==> fastybird-redisdb-exchange-plugin-0.11.0.tar.gz: fastybird-redisdb-exchange-plugin-0.11.0/README.md <==
# FastyBird Redis DB exchange plugin

[![Build Status](https://badgen.net/github/checks/FastyBird/redisdb-exchange-plugin/master?cache=300&style=flat-square)](https://github.com/FastyBird/redisdb-exchange-plugin/actions)
[![Licence](https://badgen.net/github/license/FastyBird/redisdb-exchange-plugin?cache=300&style=flat-square)](https://github.com/FastyBird/redisdb-exchange-plugin/blob/master/LICENSE.md)
[![Code coverage](https://badgen.net/coveralls/c/github/FastyBird/redisdb-exchange-plugin?cache=300&style=flat-square)](https://coveralls.io/r/FastyBird/redisdb-exchange-plugin)

![PHP](https://badgen.net/packagist/php/FastyBird/redisdb-exchange-plugin?cache=300&style=flat-square)
[![PHP latest stable](https://badgen.net/packagist/v/FastyBird/redisdb-exchange-plugin/latest?cache=300&style=flat-square)](https://packagist.org/packages/FastyBird/redisdb-exchange-plugin)
[![PHP downloads total](https://badgen.net/packagist/dt/FastyBird/redisdb-exchange-plugin?cache=300&style=flat-square)](https://packagist.org/packages/FastyBird/redisdb-exchange-plugin)
[![PHPStan](https://img.shields.io/badge/phpstan-enabled-brightgreen.svg?style=flat-square)](https://github.com/phpstan/phpstan)

![Python](https://badgen.net/pypi/python/fastybird-redisdb-exchange-plugin?cache=300&style=flat-square)
[![Python latest stable](https://badgen.net/pypi/v/fastybird-redisdb-exchange-plugin?cache=300&style=flat-square)](https://pypi.org/project/fastybird-redisdb-exchange-plugin/)
[![Python downloads month](https://img.shields.io/pypi/dm/fastybird-redisdb-exchange-plugin?cache=300&style=flat-square)](https://pypi.org/project/fastybird-redisdb-exchange-plugin/)
[![Black](https://img.shields.io/badge/black-enabled-brightgreen.svg?style=flat-square)](https://github.com/psf/black)
[![MyPy](https://img.shields.io/badge/mypy-enabled-brightgreen.svg?style=flat-square)](http://mypy-lang.org)

## What is FastyBird Redis DB exchange plugin?

This is a combined plugin for [Nette framework](https://nette.org) and [Python](https://www.python.org) which is
implementing [Redis](https://redis.io) PubSub exchange for [FastyBird](https://www.fastybird.com) IoT services

## Installation

### PHP based project:

The best way to install **fastybird/redisdb-exchange-plugin** is using [Composer](http://getcomposer.org/):

```sh
$ composer require fastybird/redisdb-exchange-plugin
```

### Python based project:

The best way to install **fastybird-redisdb-exchange-plugin** is using [Pip](https://pip.pypa.io/en/stable/):

```sh
$ pip install fastybird-redisdb-exchange-plugin
```

## Documentation

Learn how to consume & publish messages
in [documentation](https://github.com/FastyBird/redisdb-exchange-plugin/blob/master/.docs/en/index.md).

***
Homepage [https://www.fastybird.com](https://www.fastybird.com) and
repository [https://github.com/FastyBird/redisdb-exchange-plugin](https://github.com/FastyBird/redisdb-exchange-plugin).

==> fastybird-redisdb-exchange-plugin-0.49.0.tar.gz: fastybird-redisdb-exchange-plugin-0.49.0/README.md <==
# FastyBird Redis DB exchange plugin

[![Build Status](https://badgen.net/github/checks/FastyBird/redisdb-exchange-plugin/master?cache=300&style=flat-square)](https://github.com/FastyBird/redisdb-exchange-plugin/actions)
[![Licence](https://badgen.net/github/license/FastyBird/redisdb-exchange-plugin?cache=300&style=flat-square)](https://github.com/FastyBird/redisdb-exchange-plugin/blob/master/LICENSE.md)
[![Code coverage](https://badgen.net/coveralls/c/github/FastyBird/redisdb-exchange-plugin?cache=300&style=flat-square)](https://coveralls.io/r/FastyBird/redisdb-exchange-plugin)

![PHP](https://badgen.net/packagist/php/FastyBird/redisdb-exchange-plugin?cache=300&style=flat-square)
[![PHP latest stable](https://badgen.net/packagist/v/FastyBird/redisdb-exchange-plugin/latest?cache=300&style=flat-square)](https://packagist.org/packages/FastyBird/redisdb-exchange-plugin)
[![PHP downloads total](https://badgen.net/packagist/dt/FastyBird/redisdb-exchange-plugin?cache=300&style=flat-square)](https://packagist.org/packages/FastyBird/redisdb-exchange-plugin)
[![PHPStan](https://img.shields.io/badge/phpstan-enabled-brightgreen.svg?style=flat-square)](https://github.com/phpstan/phpstan)

![Python](https://badgen.net/pypi/python/fastybird-redisdb-exchange-plugin?cache=300&style=flat-square)
[![Python latest stable](https://badgen.net/pypi/v/fastybird-redisdb-exchange-plugin?cache=300&style=flat-square)](https://pypi.org/project/fastybird-redisdb-exchange-plugin/)
[![Python downloads month](https://img.shields.io/pypi/dm/fastybird-redisdb-exchange-plugin?cache=300&style=flat-square)](https://pypi.org/project/fastybird-redisdb-exchange-plugin/)
[![Black](https://img.shields.io/badge/black-enabled-brightgreen.svg?style=flat-square)](https://github.com/psf/black)
[![MyPy](https://img.shields.io/badge/mypy-enabled-brightgreen.svg?style=flat-square)](http://mypy-lang.org)

## What is FastyBird Redis DB exchange plugin?

This is a combined plugin for [FastyBird IoT](https://www.fastybird.com) ecosystem which is
implementing [Redis](https://redis.io) PubSub exchange

## Installation

### PHP based project:

The best way to install **fastybird/redisdb-exchange-plugin** is using [Composer](http://getcomposer.org/):

```sh
$ composer require fastybird/redisdb-exchange-plugin
```

### Python based project:

The best way to install **fastybird-redisdb-exchange-plugin** is using [Pip](https://pip.pypa.io/en/stable/):

```sh
$ pip install fastybird-redisdb-exchange-plugin
```

## Documentation

Learn how to consume & publish messages
in [documentation](https://github.com/FastyBird/redisdb-exchange-plugin/blob/master/.docs/en/index.md).

***
Homepage [https://www.fastybird.com](https://www.fastybird.com) and
repository [https://github.com/FastyBird/redisdb-exchange-plugin](https://github.com/FastyBird/redisdb-exchange-plugin).
